:orphan:

`xrtpy.response.temperature_from_filter_ratio`
==============================================

.. currentmodule:: xrtpy.response.temperature_from_filter_ratio

.. automodapi:: xrtpy.response.temperature_from_filter_ratio
